!function(e,t){"object"===typeof exports&&"undefined"!==typeof module?t(exports):"function"===typeof define&&define.amd?define(["exports"],t):t((e="undefined"!==typeof globalThis?globalThis:e||self).vlq={})}(this,(function(e){"use strict";let t={},n={};function o(e){let t="";e<0?e=-e<<1|1:e<<=1;do{let o=31&e;(e>>>=5)>0&&(o|=32),t+=n[o]}while(e>0);return t}"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=".split("").forEach((function(e,o){t[e]=o,n[o]=e})),e.decode=function(e){let n=[],o=0,f=0;for(let i=0;i<e.length;i+=1){let r=t[e[i]];if(void 0===r)throw new Error("Invalid character ("+e[i]+")");const l=32&r;if(r&=31,f+=r<<o,l)o+=5;else{const e=1&f;f>>>=1,e?n.push(0===f?-2147483648:-f):n.push(f),f=o=0}}return n},e.encode=function(e){if("number"===typeof e)return o(e);let t="";for(let n=0;n<e.length;n+=1)t+=o(e[n]);return t},Object.defineProperty(e,"__esModule",{value:!0})}));