button{background-color:var(--background-color);border:1px solid color-mix(in srgb,var(--text-color),#0000 80%);border-radius:.5rem;color:var(--text-color);min-height:2.5rem;padding:.25rem .75rem}button:focus{outline:none}span{font-size:20px;margin:0;padding:0}.icon{background-position:50%;background-repeat:no-repeat;background-size:contain;display:inline-block;height:20px;margin-right:.5em;width:20px}.log{background-color:var(--background-color);border:1px solid var(--primary-color);color:var(--text-color)}button:hover{background-color:var(--primary-color);color:#fff}.vertical-stepper{display:flex;flex-direction:column;gap:1.5rem;padding:1rem}.step-item{display:flex;position:relative}.step-indicator{align-items:center;background-color:var(--background-color);border:2px solid color-mix(in srgb,var(--text-color),#0000 80%);border-radius:50%;display:flex;flex-shrink:0;height:2rem;justify-content:center;margin-right:1rem;width:2rem}.step-item.done .step-indicator,.step-item.failure .step-indicator,.step-item.success .step-indicator{background-color:var(--primary-color);border-color:var(--primary-color)}.step-item.doing .step-indicator{border-color:var(--primary-color)}.check-icon,.cross-icon{color:(var(--text-color));height:1.25rem;width:1.25rem}.doing-dot{background-color:var(--primary-color);border-radius:50%;height:.75rem;width:.75rem}.step-content{flex:1 1}.step-title{font-size:1rem;font-weight:600;margin:0 0 .25rem}.step-description,.step-title{color:color-mix(in srgb,var(--text-color),#0000 80%)}.step-description{font-size:.875rem;margin:0}.step-connector{background-color:color-mix(in srgb,var(--text-color),#0000 80%);bottom:-1.5rem;left:1rem;position:absolute;top:2rem;width:2px}.step-item.done .step-connector,.step-item.failure .step-connector,.step-item.success .step-connector{background-color:var(--primary-color)}.step-item.doing .step-description,.step-item.doing .step-title,.step-item.done .step-description,.step-item.done .step-title,.step-item.failure .step-description,.step-item.failure .step-title,.step-item.success .step-description,.step-item.success .step-title{color:var(--text-color)}
/*# sourceMappingURL=main.5f4f55ec.css.map*/