from pathlib import Path

import setuptools

this_directory = Path(__file__).parent
long_description = (this_directory / 'README.md').read_text()

setuptools.setup(
    name='pera_wallet',
    version='0.0.14',
    author='code-alexander',
    author_email='',
    description='Streamlit component that allows you to connect to Pera Wallet.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='',
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[],
    python_requires='>=3.11',
    install_requires=[
        # By definition, a Custom Component depends on Streamlit.
        # If your component has other Python dependencies, list
        # them here.
        'streamlit >= 1.41',
    ],
    extras_require={
        'devel': [
            'wheel',
            'pytest==7.4.0',
            'playwright==1.48.0',
            'requests==2.31.0',
            'pytest-playwright-snapshot==1.0',
            'pytest-rerunfailures==12.0',
        ]
    },
    setup_requires=['wheel'],
)
